pub struct CommentMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on comment resources.
It is not used directly, but through the YouTube hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_youtube3 as youtube3;
use youtube3::{YouTube, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = YouTube::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `insert(...)`, `list(...)`, `mark_as_spam(...)`, `set_moderation_status(...)` and `update(...)`
// to build up your call.
let rb = hub.comments();Implementations
Sourceimpl<'a, C> CommentMethods<'a, C>
impl<'a, C> CommentMethods<'a, C>
Sourcepub fn delete(&self, id: &str) -> CommentDeleteCall<'a, C>
pub fn delete(&self, id: &str) -> CommentDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a resource.
Arguments
id- No description provided.
Sourcepub fn insert(&self, request: Comment) -> CommentInsertCall<'a, C>
pub fn insert(&self, request: Comment) -> CommentInsertCall<'a, C>
Create a builder to help you perform the following task:
Inserts a new resource into this collection.
Arguments
request- No description provided.
Sourcepub fn list(&self, part: &Vec<String>) -> CommentListCall<'a, C>
pub fn list(&self, part: &Vec<String>) -> CommentListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of resources, possibly filtered.
Arguments
part- The part parameter specifies a comma-separated list of one or more comment resource properties that the API response will include.
Sourcepub fn mark_as_spam(&self, id: &Vec<String>) -> CommentMarkAsSpamCall<'a, C>
pub fn mark_as_spam(&self, id: &Vec<String>) -> CommentMarkAsSpamCall<'a, C>
Create a builder to help you perform the following task:
Expresses the caller’s opinion that one or more comments should be flagged as spam.
Arguments
id- Flags the comments with the given IDs as spam in the caller’s opinion.
Sourcepub fn set_moderation_status(
&self,
id: &Vec<String>,
moderation_status: &str,
) -> CommentSetModerationStatuCall<'a, C>
pub fn set_moderation_status( &self, id: &Vec<String>, moderation_status: &str, ) -> CommentSetModerationStatuCall<'a, C>
Create a builder to help you perform the following task:
Sets the moderation status of one or more comments.
Arguments
id- Modifies the moderation status of the comments with the given IDsmoderationStatus- Specifies the requested moderation status. Note, comments can be in statuses, which are not available through this call. For example, this call does not allow to mark a comment as ‘likely spam’. Valid values: ‘heldForReview’, ‘published’ or ‘rejected’.
Sourcepub fn update(&self, request: Comment) -> CommentUpdateCall<'a, C>
pub fn update(&self, request: Comment) -> CommentUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates an existing resource.
Arguments
request- No description provided.