pub struct CommentThreadSnippet {
pub can_reply: Option<bool>,
pub channel_id: Option<String>,
pub is_public: Option<bool>,
pub post_id: Option<String>,
pub top_level_comment: Option<Comment>,
pub total_reply_count: Option<u32>,
pub video_id: Option<String>,
}Expand description
Basic details about a comment thread.
This type is not used in any activity, and only used as part of another schema.
Fields
can_reply: Option<bool>Whether the current viewer of the thread can reply to it. This is viewer specific - other viewers may see a different value for this field.
channel_id: Option<String>The YouTube channel the comments in the thread refer to or the channel with the video the comments refer to. If neither video_id nor post_id is set the comments refer to the channel itself.
is_public: Option<bool>Whether the thread (and therefore all its comments) is visible to all YouTube users.
post_id: Option<String>The ID of the post the comments refer to, if any.
top_level_comment: Option<Comment>The top level comment of this thread.
total_reply_count: Option<u32>The total number of replies (not including the top level comment).
video_id: Option<String>The ID of the video the comments refer to, if any.