pub struct ThirdPartyLinkMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on thirdPartyLink resources.
It is not used directly, but through the YouTube hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_youtube3 as youtube3;
use youtube3::{YouTube, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = YouTube::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `insert(...)`, `list(...)` and `update(...)`
// to build up your call.
let rb = hub.third_party_links();Implementations
Sourceimpl<'a, C> ThirdPartyLinkMethods<'a, C>
impl<'a, C> ThirdPartyLinkMethods<'a, C>
Sourcepub fn delete(
&self,
linking_token: &str,
type_: &str,
) -> ThirdPartyLinkDeleteCall<'a, C>
pub fn delete( &self, linking_token: &str, type_: &str, ) -> ThirdPartyLinkDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a resource.
Arguments
linkingToken- Delete the partner links with the given linking token.type- Type of the link to be deleted.
Sourcepub fn insert(&self, request: ThirdPartyLink) -> ThirdPartyLinkInsertCall<'a, C>
pub fn insert(&self, request: ThirdPartyLink) -> ThirdPartyLinkInsertCall<'a, C>
Create a builder to help you perform the following task:
Inserts a new resource into this collection.
Arguments
request- No description provided.
Sourcepub fn list(&self, part: &Vec<String>) -> ThirdPartyLinkListCall<'a, C>
pub fn list(&self, part: &Vec<String>) -> ThirdPartyLinkListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of resources, possibly filtered.
Arguments
part- The part parameter specifies the thirdPartyLink resource parts that the API response will include. Supported values are linkingToken, status, and snippet.
Sourcepub fn update(&self, request: ThirdPartyLink) -> ThirdPartyLinkUpdateCall<'a, C>
pub fn update(&self, request: ThirdPartyLink) -> ThirdPartyLinkUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates an existing resource.
Arguments
request- No description provided.