pub struct ThumbnailMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on thumbnail resources.
It is not used directly, but through the YouTube hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_youtube3 as youtube3;
use youtube3::{YouTube, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = YouTube::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `set(...)`
// to build up your call.
let rb = hub.thumbnails();Implementations
Sourceimpl<'a, C> ThumbnailMethods<'a, C>
impl<'a, C> ThumbnailMethods<'a, C>
Sourcepub fn set(&self, video_id: &str) -> ThumbnailSetCall<'a, C>
pub fn set(&self, video_id: &str) -> ThumbnailSetCall<'a, C>
Create a builder to help you perform the following task:
As this is not an insert in a strict sense (it supports uploading/setting of a thumbnail for multiple videos, which doesn’t result in creation of a single resource), I use a custom verb here.
Arguments
videoId- Returns the Thumbnail with the given video IDs for Stubby or Apiary.