pub struct VideoMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on video resources.
It is not used directly, but through the YouTube hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_youtube3 as youtube3;
use youtube3::{YouTube, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = YouTube::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get_rating(...)`, `insert(...)`, `list(...)`, `rate(...)`, `report_abuse(...)` and `update(...)`
// to build up your call.
let rb = hub.videos();Implementations
Sourceimpl<'a, C> VideoMethods<'a, C>
impl<'a, C> VideoMethods<'a, C>
Sourcepub fn delete(&self, id: &str) -> VideoDeleteCall<'a, C>
pub fn delete(&self, id: &str) -> VideoDeleteCall<'a, C>
Create a builder to help you perform the following task:
Deletes a resource.
Arguments
id- No description provided.
Sourcepub fn get_rating(&self, id: &Vec<String>) -> VideoGetRatingCall<'a, C>
pub fn get_rating(&self, id: &Vec<String>) -> VideoGetRatingCall<'a, C>
Create a builder to help you perform the following task:
Retrieves the ratings that the authorized user gave to a list of specified videos.
Arguments
id- No description provided.
Sourcepub fn insert(&self, request: Video) -> VideoInsertCall<'a, C>
pub fn insert(&self, request: Video) -> VideoInsertCall<'a, C>
Create a builder to help you perform the following task:
Inserts a new resource into this collection.
Arguments
request- No description provided.
Sourcepub fn list(&self, part: &Vec<String>) -> VideoListCall<'a, C>
pub fn list(&self, part: &Vec<String>) -> VideoListCall<'a, C>
Create a builder to help you perform the following task:
Retrieves a list of resources, possibly filtered.
Arguments
part- The part parameter specifies a comma-separated list of one or more video resource properties that the API response will include. If the parameter identifies a property that contains child properties, the child properties will be included in the response. For example, in a video resource, the snippet property contains the channelId, title, description, tags, and categoryId properties. As such, if you set part=snippet, the API response will contain all of those properties.
Sourcepub fn rate(&self, id: &str, rating: &str) -> VideoRateCall<'a, C>
pub fn rate(&self, id: &str, rating: &str) -> VideoRateCall<'a, C>
Create a builder to help you perform the following task:
Adds a like or dislike rating to a video or removes a rating from a video.
Arguments
id- No description provided.rating- No description provided.
Sourcepub fn report_abuse(
&self,
request: VideoAbuseReport,
) -> VideoReportAbuseCall<'a, C>
pub fn report_abuse( &self, request: VideoAbuseReport, ) -> VideoReportAbuseCall<'a, C>
Create a builder to help you perform the following task:
Report abuse for a video.
Arguments
request- No description provided.
Sourcepub fn update(&self, request: Video) -> VideoUpdateCall<'a, C>
pub fn update(&self, request: Video) -> VideoUpdateCall<'a, C>
Create a builder to help you perform the following task:
Updates an existing resource.
Arguments
request- No description provided.