pub struct VideoStat {
pub content_details: Option<VideoStatsContentDetails>,
pub etag: Option<String>,
pub id: Option<String>,
pub kind: Option<String>,
pub snippet: Option<VideoStatsSnippet>,
pub statistics: Option<VideoStatsStatistics>,
}Expand description
A VideoStat resource represents a YouTube video’s stats.
This type is not used in any activity, and only used as part of another schema.
Fields
content_details: Option<VideoStatsContentDetails>Output only. The VideoStatsContentDetails object contains information about the video content, including the length of the video.
etag: Option<String>Output only. Etag of this resource.
id: Option<String>Output only. The ID that YouTube uses to uniquely identify the video.
kind: Option<String>Output only. Identifies what kind of resource this is. Value: the fixed string “youtube#videoStats”.
snippet: Option<VideoStatsSnippet>Output only. The VideoStatsSnippet object contains basic details about the video, such publish time.
statistics: Option<VideoStatsStatistics>Output only. The VideoStatsStatistics object contains statistics about the video.