pub struct VideoStatsContentDetails {
pub duration: Option<Duration>,
}Expand description
Details about the content of a YouTube Video. This is a subset of the information in VideoContentDetails specifically for the Videos.stats API.
This type is not used in any activity, and only used as part of another schema.
Fields
duration: Option<Duration>Output only. The length of the video. The property value is a google.protobuf.Duration object.