pub struct VideoStatsSnippet {
pub publish_time: Option<DateTime<Utc>>,
}Expand description
Basic details about a video. This is a subset of the information in VideoSnippet specifically for the Videos.stats API.
This type is not used in any activity, and only used as part of another schema.
Fields
publish_time: Option<DateTime<Utc>>Output only. The date and time that the video was uploaded. The property value is a google.protobuf.Timestamp object.