pub struct VideoStatsStatistics {
pub comment_count: Option<i64>,
pub like_count: Option<i64>,
pub view_count: Option<i64>,
}Expand description
Statistics about the video, such as the number of times the video was viewed or liked.
This type is not used in any activity, and only used as part of another schema.
Fields
comment_count: Option<i64>Output only. The number of comments for the video.
like_count: Option<i64>Output only. The number of users who have indicated that they liked the video by giving it a positive rating.
view_count: Option<i64>Output only. The number of times the video has been viewed.